InMemoryCache

Struct InMemoryCache 

pub struct InMemoryCache<K, V, H = RandomState>
where K: Hash + Eq + Send + Sync + 'static, V: Clone + Send + Sync + 'static, H: BuildHasher + Clone + Send + Sync + 'static,
{ /* private fields */ }
Available on crate features memory only.
A concurrent in-memory cache tier.

This cache provides:

  • Concurrent access with high performance
  • Automatic eviction based on capacity
  • Thread-safe operations

Examples

use cachet_memory::InMemoryCache;
use cachet_tier::{CacheEntry, CacheTier};


let cache = InMemoryCache::<String, i32>::new();

cache
    .insert("key".to_string(), CacheEntry::new(42))
    .await
    .unwrap();
let value = cache.get(&"key".to_string()).await.unwrap();
assert_eq!(*value.unwrap().value(), 42);

Implementations

Source

impl<K, V> InMemoryCache<K, V>
where K: Hash + Eq + Send + Sync + 'static, V: Clone + Send + Sync + 'static,

pub fn new() -> InMemoryCache<K, V>

Creates a new unbounded in-memory cache.

The cache will use default eviction policy (TinyLFU).

Examples
use cachet_memory::InMemoryCache;

let cache = InMemoryCache::<String, i32>::new();
pub fn with_max_capacity(max_capacity: u64) -> InMemoryCache<K, V>

Creates a new in-memory cache with a maximum capacity.

Once the capacity is reached, entries will be evicted using the TinyLFU policy (combination of LRU eviction and LFU admission).

Examples
use cachet_memory::InMemoryCache;

let cache = InMemoryCache::<String, i32>::with_max_capacity(1000);
pub fn builder() -> InMemoryCacheBuilder<K, V>

Creates a new builder for configuring an in-memory cache.

The builder provides access to additional configuration options such as time-to-live, time-to-idle, and initial capacity.

Examples
use std::time::Duration;

use cachet_memory::InMemoryCache;

let cache = InMemoryCache::<String, i32>::builder()
    .max_capacity(1000)
    .time_to_live(Duration::from_secs(300))
    .time_to_idle(Duration::from_secs(60))
    .build();